@@ -305,7 +305,7 @@
 # define H5Z_FILTER_BLOSC 32001
 #endif
 
-/* define MAX CHUNK SIZE here as its not present in netcdf.h */
+/* Define MAX CHUNK SIZE here since it is not present in netcdf.h */
 #define NCO_MAX_CHUNK_SIZE (0xFFFFFFFF)
 
 #ifdef __cplusplus
@@ -353,7 +353,8 @@ f90_typ_nm /* [fnc] Return string describing native Fortran90 type */
 (const nc_type type); /* I [enm] netCDF type */
 
 void
-nco_dfl_case_generic_err(void); /* [fnc] Print error and exit for illegal switch case */
+nco_dfl_case_generic_err /* [fnc] Print error and exit for illegal switch case */
+(const int case_arg_int); /* I [enm] Value of case argument that fell through to default case */
 
 void
 nco_dfl_case_flt_err(void); /* [fnc] Print error and exit for illegal switch(nco_flt_enm) case */
@@ -532,6 +533,10 @@ int nco_inq_enum_member(const int nc_id,const nc_type var_typ,const int idx,char
 int nco_inq_enum_ident(const int nc_id,const nc_type var_typ,const long long val,char * const mbr_nm);
 /* End enum routines */
 
+/* Begin string routines (_string) */
+int nco_free_string(const size_t sz,char ** const sngp);
+/* End string routines */
+
 /* Begin vlen routines (_vlen) */
 int nco_def_vlen(const int nc_id,const char * const typ_nm,const nc_type bs_typ,nc_type * const vlen_typ);
 int nco_inq_vlen(const int nc_id,const nc_type vlen_typ,char * const typ_nm,size_t * const typ_sz,nc_type * const bs_typ);
